@@ -1,5 +1,5 @@
 package Bio::ToolBox::Data;
-our $VERSION = '1.64';
+our $VERSION = '1.66';
 
 =head1 NAME
 
@@ -1070,10 +1070,16 @@ L<Bio::DB::SeqFeature::Store>, L<Bio::Perl>
 =cut
 
 use strict;
+use File::Spec;
 use Carp qw(carp cluck croak confess);
 use base 'Bio::ToolBox::Data::core';
+use Bio::ToolBox::db_helper qw(
+	get_new_feature_list  
+	get_new_genome_list
+	get_db_feature
+	calculate_score
+);
 use Module::Load;
-my $db_loaded;
 
 1;
 
@@ -1093,19 +1099,9 @@ sub new {
 	
 	# check for stream
 	if ($args{stream}) {
-		my $obj;
-		eval {
-			$class = "Bio::ToolBox::Data::Stream";
-			load $class;
-			$obj = $class->new(@_);
-		};
-		if ($obj) {
-			return $obj;
-		}
-		else {
-			carp "cannot load Stream object $@";
-			return;
-		}
+		$class = "Bio::ToolBox::Data::Stream";
+		load($class);
+		return $class->new(@_);
 	}
 	
 	# initialize
@@ -1139,11 +1135,6 @@ sub new {
 		$self->feature($args{features});
 		$self->database($args{db});
 		$args{data} = $self;
-		unless ($db_loaded) {
-			load('Bio::ToolBox::db_helper', qw(get_new_feature_list  
-				get_new_genome_list get_db_feature));
-			$db_loaded = 1;
-		}
 		my $result;
 		if ($args{features} eq 'genome') {
 			$result = get_new_genome_list(%args);
@@ -1584,11 +1575,6 @@ sub collapse_gene_transcripts {
 	else {
 		# no stored SeqFeature objects, probably names pointing to a database
 		# we will have to fetch the feature from a database
-		unless ($db_loaded) {
-			load('Bio::ToolBox::db_helper', qw(get_new_feature_list  
-				get_new_genome_list get_db_feature));
-			$db_loaded = 1;
-		}
 		my $db = $self->open_meta_database(1) or  # force open a new db connection
 			confess "No SeqFeature objects stored and no database connection!";
 		my $name_i = $self->name_column;
@@ -1664,11 +1650,6 @@ sub add_transcript_length {
 		# we will have to fetch the feature from a database
 		my $db = $self->open_meta_database(1) or  # force open a new db connection
 			confess "No SeqFeature objects stored and no database connection!";
-		unless ($db_loaded) {
-			load('Bio::ToolBox::db_helper', qw(get_new_feature_list  
-				get_new_genome_list get_db_feature));
-			$db_loaded = 1;
-		}
 		my $name_i = $self->name_column;
 		my $id_i = $self->id_column;
 		my $type_i = $self->type_column;
@@ -2087,16 +2068,6 @@ sub summary_file {
 	# Collect passed arguments
 	my %args = @_; 
 	
-	# load modules
-	eval {
-		my $class = 'Statistics::Lite';
-		load($class, qw(min mean));
-	};
-	if ($@) {
-		carp "missing required modules! $@";
-		return;
-	}
-	
 	# parameters
 	my $outfile =        $args{'filename'}    || undef;
 	my $dataset =        $args{'dataset'}     || undef;
@@ -2130,7 +2101,8 @@ sub summary_file {
 		my @acceptable_indices; # array of acceptable indices
 		my %skip = map {$_ => 1} qw (systematicname name id alias aliases type class 
 				geneclass chromosome chromo seq_id seqid start stop end gene strand 
-				length primary_id);
+				length primary_id merged_transcript_length transcript_cds_length 
+				transcript_5p_utr_length transcript_3p_utr_length);
 		
 		# walk through the dataset names
 		for (my $i = 0; $i < $self->number_columns; $i++) {
@@ -2143,7 +2115,7 @@ sub summary_file {
 		# acceptable_indices array.
 		# Assuming, of course, that feature descriptor datasets (columns) are
 		# leftmost only.
-		$startcolumn = min(@acceptable_indices);
+		$startcolumn = calculate_score('min', \@acceptable_indices);
 	}
 	unless (defined $endcolumn) {
 		# take the last or rightmost column
@@ -2153,8 +2125,6 @@ sub summary_file {
 		# the original dataset name (i.e. the name of the dataset in the 
 		# database from which the column's data was derived) 
 		$dataset = $self->metadata($startcolumn, 'dataset') || undef;
-		$dataset =~ s/^(?:file|http|ftp):\/*//;
-		$dataset =~ s/\.(?:bw|bam|bb|big.*|useq)$//;
 	}
 	unless (defined $log) {
 		# the log flag should be set in the column metadata and should be the
@@ -2163,7 +2133,31 @@ sub summary_file {
 	}
 	
 	# Prepare score column name
-	my $data_name = $dataset ? $dataset : $self->basename ? $self->basename : 'dataset';
+	my $data_name;
+	if ($dataset =~ /^(?:file|http|ftp):\/*(.+)$/) {
+		my $d = $1;
+		# a specified file
+		# we just want the file name, split it from the path
+		foreach (split /&/, $d) {
+			my (undef, undef, $file_name) = File::Spec->splitpath($_);
+			# clean up extensions and stuff
+			$file_name =~ s/^([\w\d\-\_]+)\..+$/$1/i; # take everything up to first .
+			if ($data_name) {
+				$data_name .= '&' . $file_name;
+			}
+			else {
+				$data_name = $file_name;
+			}
+		}
+	}
+	elsif ($dataset) {
+		# a feature type, take as is
+		$data_name = $dataset;
+	}
+	else {
+		# super generic, what else to do?
+		$data_name = 'dataset';
+	}
 	
 	# Prepare array to store the summed data
 	my $summed_data = $self->new(
@@ -2186,11 +2180,10 @@ sub summary_file {
 	) { 
 		
 		# determine the midpoint position of the window
-		my $midpoint = int mean(
+		my $midpoint = int calculate_score('mean',
 			# this assumes the column metadata has start and stop
-			$self->metadata($column, 'start'),	
-			$self->metadata($column, 'stop'),	
-		) or undef; 
+			[$self->metadata($column, 'start'), $self->metadata($column, 'stop')]
+		); 
 		
 		# convert midpoint to fraction of 1000 for plotting if necessary
 		if (substr($self->name($column), -1) eq '%') {
@@ -2215,7 +2208,7 @@ sub summary_file {
 		}
 		
 		# determine mean value
-		my $window_mean = mean(@values);
+		my $window_mean = calculate_score('mean', \@values);
 		if ($log) { 
 			$window_mean = log($window_mean) / log(2);
 		}
